@@ -1,9 +1,6 @@
-# -*- coding: utf-8 -*-
-
 import sys
 
 from prospector.run import main
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main())
