@@ -2,16 +2,17 @@ import os
 import re
 import sre_constants
 import sys
+from typing import List
 
 from prospector import tools
 from prospector.autodetect import autodetect_libraries
 from prospector.config import configuration as cfg
 from prospector.profiles import AUTO_LOADED_PROFILES
 from prospector.profiles.profile import BUILTIN_PROFILE_PATH, CannotParseProfile, ProfileNotFound, ProspectorProfile
-from prospector.tools import DEFAULT_TOOLS
+from prospector.tools import DEFAULT_TOOLS, DEPRECATED_TOOL_NAMES
 
 
-class ProspectorConfig(object):
+class ProspectorConfig:
     # There are several methods on this class which could technically
     # be functions (they don't use the 'self' argument) but that would
     # make this module/class a bit ugly.
@@ -52,6 +53,20 @@ class ProspectorConfig(object):
             runners.append(tool)
         return runners
 
+    def replace_deprecated_tool_names(self) -> List[str]:
+        # pep8 was renamed pycodestyle ; pep257 was renamed pydocstyle
+        # for backwards compatibility, these have been deprecated but will remain until prospector v2
+        deprecated_found = []
+        replaced = []
+        for tool_name in self.tools_to_run:
+            if tool_name in DEPRECATED_TOOL_NAMES:
+                replaced.append(DEPRECATED_TOOL_NAMES[tool_name])
+                deprecated_found.append(tool_name)
+            else:
+                replaced.append(tool_name)
+        self.tools_to_run = replaced
+        return deprecated_found
+
     def get_output_report(self):
         # Get the output formatter
         if self.config.output_format is not None:
@@ -197,13 +212,15 @@ class ProspectorConfig(object):
             if tool in to_run:
                 to_run.remove(tool)
 
-        if config.tools is None and len(config.with_tools) == 0 and len(config.without_tools) == 0:
-            for tool in tools.TOOLS.keys():
-                enabled = profile.is_tool_enabled(tool)
-                if enabled is None:
-                    enabled = tool in DEFAULT_TOOLS
-                if tool in to_run and not enabled:
-                    to_run.remove(tool)
+        # if config.tools is None and len(config.with_tools) == 0 and len(config.without_tools) == 0:
+        for tool in tools.TOOLS.keys():
+            enabled = profile.is_tool_enabled(tool)
+            if enabled is None:
+                enabled = tool in DEFAULT_TOOLS
+            if tool in to_run and not enabled and tool not in config.with_tools and tool not in (config.tools or []):
+                # if this is not enabled in a profile but is asked for in a command line arg, we keep it, otherwise
+                # remove it from the list to run
+                to_run.remove(tool)
 
         return sorted(list(to_run))
 
@@ -276,6 +293,10 @@ class ProspectorConfig(object):
     def messages_only(self):
         return self.config.messages_only
 
+    @property
+    def quiet(self):
+        return self.config.quiet
+
     @property
     def blending(self):
         return self.config.blending
@@ -299,3 +320,7 @@ class ProspectorConfig(object):
     @property
     def show_profile(self):
         return self.config.show_profile
+
+    @property
+    def legacy_tool_names(self) -> bool:
+        return self.config.legacy_tool_names
