@@ -15,5 +15,5 @@ class OutputChoice(Choice):
                 checked_targets[-1] += ":" + target
             else:
                 checked_targets.append(target)
-        validated_format = super(OutputChoice, self).sanitize(output_format)
+        validated_format = super().sanitize(output_format)
         return (validated_format, checked_targets)
