@@ -2,9 +2,9 @@ from prospector.exceptions import FatalProspectorException
 from prospector.tools.base import ToolBase
 from prospector.tools.dodgy import DodgyTool
 from prospector.tools.mccabe import McCabeTool
-from prospector.tools.pep8 import Pep8Tool
-from prospector.tools.pep257 import Pep257Tool
 from prospector.tools.profile_validator import ProfileValidationTool
+from prospector.tools.pycodestyle import PycodestyleTool
+from prospector.tools.pydocstyle import PydocstyleTool
 from prospector.tools.pyflakes import PyFlakesTool
 from prospector.tools.pylint import PylintTool
 
@@ -39,9 +39,9 @@ TOOLS = {
     "dodgy": DodgyTool,
     "mccabe": McCabeTool,
     "pyflakes": PyFlakesTool,
-    "pep8": Pep8Tool,
+    "pycodestyle": PycodestyleTool,
     "pylint": PylintTool,
-    "pep257": Pep257Tool,
+    "pydocstyle": PydocstyleTool,
     "profile-validator": ProfileValidationTool,
     "frosted": _optional_tool("frosted"),
     "vulture": _optional_tool("vulture"),
@@ -55,8 +55,10 @@ DEFAULT_TOOLS = (
     "dodgy",
     "mccabe",
     "pyflakes",
-    "pep8",
+    "pycodestyle",
     "pylint",
-    "pep257",
+    "pydocstyle",
     "profile-validator",
 )
+
+DEPRECATED_TOOL_NAMES = {"pep8": "pycodestyle", "pep257": "pydocstyle"}
