@@ -1,8 +1,7 @@
-from __future__ import absolute_import
-
 import ast
 
 from mccabe import PathGraphingAstVisitor
+
 from prospector.encoding import CouldNotHandleEncoding, read_py_file
 from prospector.message import Location, Message, make_tool_error_message
 from prospector.tools.base import ToolBase
@@ -12,7 +11,7 @@ __all__ = ("McCabeTool",)
 
 class McCabeTool(ToolBase):
     def __init__(self, *args, **kwargs):
-        super(McCabeTool, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.ignore_codes = ()
         self.max_complexity = 10
 
