@@ -1,7 +1,9 @@
+import codecs
 import re
 import sre_constants
 
 import yaml
+
 from prospector.message import Location, Message
 from prospector.profiles import AUTO_LOADED_PROFILES
 from prospector.tools import ToolBase, pyflakes
@@ -45,18 +47,19 @@ class ProfileValidationTool(ToolBase):
 
         self.ignore_codes = prospector_config.get_disabled_messages("profile-validator")
 
-    def tool_names(self):
+    def tool_names(self):  # pylint: disable=no-self-use, cyclic-import
         # TODO: this is currently a circular import, which is why it is not at the top of
         # the module. However, there's no obvious way to get around this right now...
-        # pylint: disable=cyclic-import
-        from prospector.tools import TOOLS
+        from prospector.tools import TOOLS  # pylint: disable=import-outside-toplevel
 
         return TOOLS.keys()
 
     def validate(self, relative_filepath, absolute_filepath):
+        # pylint: disable=consider-using-f-string, too-many-locals, too-many-branches
+        # TODO: this should be broken down into smaller pieces
         messages = []
 
-        with open(absolute_filepath) as profile_file:
+        with codecs.open(absolute_filepath) as profile_file:
             raw_contents = profile_file.read()
             parsed = yaml.safe_load(raw_contents)
             raw_contents = raw_contents.split("\n")
@@ -77,7 +80,7 @@ class ProfileValidationTool(ToolBase):
             # this happens if a completely empty profile is found
             add_message(
                 PROFILE_IS_EMPTY,
-                "%s is a completely empty profile" % relative_filepath,
+                f"{relative_filepath} is a completely empty profile",
                 "entire-file",
             )
             return messages
@@ -86,7 +89,7 @@ class ProfileValidationTool(ToolBase):
             if not isinstance(parsed.get(setting, False), bool):
                 add_message(
                     CONFIG_SETTING_MUST_BE_BOOL,
-                    '"%s" should be true or false' % setting,
+                    f'"{setting}" should be true or false',
                     setting,
                 )
 
@@ -147,7 +150,7 @@ class ProfileValidationTool(ToolBase):
             if key not in parsed:
                 continue
             if not isinstance(parsed[key], (tuple, list)):
-                add_message(CONFIG_SETTING_SHOULD_BE_LIST, '"%s" should be a list' % key, key)
+                add_message(CONFIG_SETTING_SHOULD_BE_LIST, f'"{key}" should be a list', key)
 
         for key in parsed.keys():
             if key not in ProfileValidationTool.ALL_SETTINGS and key not in self.tool_names():
