@@ -2,17 +2,18 @@ import os
 import re
 import sys
 from collections import defaultdict
+from typing import List
 
-from prospector.message import Location, Message
-from prospector.tools.base import ToolBase
-from prospector.tools.pylint.collector import Collector
-from prospector.tools.pylint.indent_checker import IndentChecker
-from prospector.tools.pylint.linter import ProspectorLinter
 from pylint.config import find_pylintrc
 from pylint.exceptions import UnknownMessageError
 from pylint.lint.run import _cpu_count
 
-_UNUSED_WILDCARD_IMPORT_RE = re.compile(r"^Unused import (.*) from wildcard import$")
+from prospector.message import Location, Message
+from prospector.tools.base import ToolBase
+from prospector.tools.pylint.collector import Collector
+from prospector.tools.pylint.linter import ProspectorLinter
+
+_UNUSED_WILDCARD_IMPORT_RE = re.compile(r"^Unused import(\(s\))? (.*) from wildcard import")
 
 
 class PylintTool(ToolBase):
@@ -73,13 +74,6 @@ class PylintTool(ToolBase):
         linter.enable("suppressed-message")  # notification about a message being suppressed
         linter.disable("deprecated-pragma")  # notification about use of deprecated 'pragma' option
 
-        # disable the 'mixed indentation' warning, since it actually will only
-        # allow the indentation specified in the pylint configuration file; we
-        # replace it instead with our own version which is more lenient and
-        # configurable
-        indent_checker = IndentChecker(linter)
-        linter.register_checker(indent_checker)
-
         max_line_length = prospector_config.max_line_length
         for checker in linter.get_checkers():
             if not hasattr(checker, "options"):
@@ -125,16 +119,6 @@ class PylintTool(ToolBase):
             check_paths, config_messages, configured_by, ext_found, linter, prospector_config, pylint_options
         )
 
-        # Pylint 1.4 introduced the idea of explicitly specifying which
-        # C-extensions to load. This is because doing so allows them to
-        # execute any code whatsoever, which is considered to be unsafe.
-        # The following option turns off this, allowing any extension to
-        # load again, since any setup.py can execute arbitrary code and
-        # the safety gained through this approach seems minimal. Leaving
-        # it on means that the inference engine cannot do much inference
-        # on modules with C-extensions which is a bit useless.
-        linter.set_option("unsafe-load-any-extension", True)
-
         # we don't want similarity reports right now
         linter.disable("similarities")
 
@@ -198,9 +182,11 @@ class PylintTool(ToolBase):
             if pylintrc is None:
                 pylintrc = find_pylintrc()
             if pylintrc is None:
-                pylintrc_path = os.path.join(prospector_config.workdir, ".pylintrc")
-                if os.path.exists(pylintrc_path):
-                    pylintrc = pylintrc_path
+                for possible in (".pylintrc", "pylintrc", "pyproject.toml", "setup.cfg"):
+                    pylintrc_path = os.path.join(prospector_config.workdir, possible)
+                    if os.path.exists(pylintrc_path):
+                        pylintrc = pylintrc_path
+                        break
 
             if pylintrc is not None:
                 # load it!
@@ -254,7 +240,7 @@ class PylintTool(ToolBase):
         combined = self._combine_w0614(messages)
         return sorted(combined)
 
-    def run(self, found_files):
+    def run(self, found_files) -> List[Message]:
         self._linter.check(self._args)
         sys.path = self._orig_sys_path
 
